#Script to compare ECM data from this study with Tian et al 2019 PNAS
setwd("YOUR DIR")

#Load the correct ensembl for survival analysis further below 
#Use biomaRt to convert Hugo symbols to Entrezgene symbols but don't load it into the environment as it will mask some functions from tidyvsere
install.packages("biomaRt") 

#Call in ensemble and select human mart (requires internet connection)!
ensembl <- biomaRt::useMart("ensembl")
ensembl = biomaRt::useDataset("hsapiens_gene_ensembl", mart = ensembl)

#Get packages
require(tidyverse)
require(ggplot2)
require(ggExtra)
require(ggrepel)
require(ggpubr)
library(survival)
library(survminer)
require(scales)

#Part I
#Get the MAsome_FC file from B_2020_SF1_PDA-ECM.zip/2020_F1_PDA-ECM.R
MAsome_FC <- read.csv("Masterfile_annotated_FC.csv", sep = ",", header = TRUE) %>% select(Accession, Gene_name, Division, Category, mean_1:T12vNP_R)

#Get file with all protein data from the PDAs using MAsome_FC as input 
MA_PDA <- MAsome_FC %>% select(Gene_name, Category, Division,
                               T9vNP, 
                               T12vNP,
                               T3vNP,
                               T6vNP, 
                               T1vNP) %>% 
  pivot_longer(-c("Gene_name", "Category", "Division"), names_to = "sample") %>%
  group_by(Gene_name, Category, Division) %>% 
  nest() %>%
  ungroup()

#PanIN List 
MA_PanIN <- MAsome_FC %>% select(Gene_name,
                               T10vNP,
                               T4vNP,
                               T5vNP,
                               T11vNP,
                               T8vNP) %>% 
  pivot_longer(-c("Gene_name"), names_to = "sample") %>%
  group_by(Gene_name) %>% 
  nest() %>%
  ungroup()


#Function to get mean across all values for each of the tumours 
f2 <- function(x){
  mean <- mean(x$value)
  res <- data.frame(mean)
  return(res)
}  

#Get table with mean values for each protein
MA_fPDA <- MA_PDA %>%
  mutate(data2 = map(.x = data, .f = f2)) %>%
  select(-data) %>%
  unnest(cols = c(data2))

MA_fPanIN <- MA_PanIN %>%
  mutate(data2 = map(.x = data, .f = f2)) %>%
  select(-data) %>%
  unnest(cols = c(data2))

#Merge PanIN and PDA table
MA_CB_merge = full_join(MA_fPDA %>% 
                          select(Gene_name, Division, Category, Log2PDAvWT_CB = mean), 
                        MA_fPanIN %>% 
                          select(Gene_name, Log2PanINvWT_CB = mean),
                        by = "Gene_name")

#Import Tuveson data (murine, all Log2FC) - Data is in Supplementary Data 1G - termed "Tian2019_SD1G.csv"
TH_MA <- read_csv("Tian2019_SD1G.csv") %>%
  select(Division = "Matrisome Division",
         Category = "Matrisome Category",
         Gene = "Entrez Gene Symbol",
         Log2FC_control = "Log2(fold changes) (PDAC/WT)",
         WT1:PDAC3)

#Get mean for all Log2FC values across columns for different disease stages 
TH_MA$mean_wt = apply(TH_MA[,5:7], 1, mean)
TH_MA$mean_EP = apply(TH_MA[,8:10], 1, mean)
TH_MA$mean_LP = apply(TH_MA[,11:13], 1, mean)
TH_MA$mean_PanIN = apply(TH_MA[,8:13], 1, mean)
TH_MA$mean_PDA = apply(TH_MA[,14:16], 1, mean)

#Get Log2FC X vs WT in Tian et al dataset 
TH_MA <- TH_MA %>% mutate(Log2PDAvWT = mean_PDA - mean_wt,
                          Log2EPvWT = mean_EP - mean_wt,
                          Log2LPvWT = mean_LP - mean_wt, 
                          Log2PanINvWT = mean_PanIN - mean_wt) %>%
  select(Gene_name = Gene, Log2PDAvWT, Log2EPvWT, Log2LPvWT, Log2PanINvWT)

#Left join of matrisome proteins onto ECM data in this study
MA_merge_full <- left_join(MA_CB_merge, TH_MA, by = "Gene_name")

#Inner join of both datasets
MA_merge <- inner_join(MA_CB_merge, TH_MA, by = "Gene_name")

#Join of only core matrisome 
MA_merge_c <- MA_merge %>% filter(Division == "Core matrisome")

#Select only tumour samples in MA_merge and get mean across all tumour samples from this study 
MA_merge_NRA <- MA_merge %>% inner_join(MAsome_FC %>% select(Gene_name, 
                                                             mean_9,
                                                             mean_12,
                                                             mean_3, 
                                                             mean_6,
                                                             mean_1),
                                        by = "Gene_name")

MA_merge_NRA["mean_PDA"] = apply(MA_merge_NRA[10:14], 1, function(x) mean(x))


#Save merged tables 
write_csv(MA_merge_NRA %>% select(-c(mean_9:mean_1)), "./Below_Tian_inner_mean.csv", na = "")
write_csv(MA_merge_full, "./Below_Tian_full.csv", na = "")
write_csv(MA_merge, "./Below_Tian_inner.csv", na = "")


#Generate bargraphs in the matrisome indicating the changes, only use the full matrisome shared between Below and Tian datasets
#Helper function to count the regulation of matrisomal proteins 
f_gene_counter <- function(tbl){
  up = NROW(tbl %>% filter(Log2PDAvWT_CB >= 1))
  down = NROW(tbl %>% filter(Log2PDAvWT_CB <= -1))
  tot = NROW(tbl)
  stable = tot - up - down
  res = data.frame("1_up" = up, "3_down" = down, "2_stable"=stable, "4_tot"=tot)
  return(res)
} 

#Get the changes of matrisome proteins for each category of the matrisome using the f_gene_counter
MA_bars_cat <- MA_merge %>% select(Gene_name, Category, Log2PDAvWT_CB) %>% 
  group_by(Category) %>%
  nest() %>%
  ungroup() %>%
  mutate(data2 = map(.x = data, .f = f_gene_counter)) %>%
  unnest(cols = c(data, data2)) %>%
  mutate(X1_per_up = X1_up/X4_tot,
         X3_per_down = X3_down/X4_tot,
         X2_per_stable = X2_stable/X4_tot) %>%
  select(-Gene_name, -Log2PDAvWT_CB) %>%
  distinct()

#Get the changes of matrisome proteins for each division of the matrisome using the f_gene_counter
MA_bars_div <- MA_merge %>% select(Gene_name, Category = Division, Log2PDAvWT_CB) %>% 
  group_by(Category) %>%
  nest() %>%
  ungroup() %>%
  mutate(data2 = map(.x = data, .f = f_gene_counter)) %>%
  unnest(cols = c(data, data2)) %>%
  mutate(X1_per_up = X1_up/X4_tot,
         X3_per_down = X3_down/X4_tot,
         X2_per_stable = X2_stable/X4_tot) %>%
  select(-Gene_name, -Log2PDAvWT_CB) %>%
  distinct() 

#Merge the changes for category and division together and generate a plot 
MA_bars <- rbind(MA_bars_div, MA_bars_cat) %>% select(Category, X1_per_up, X2_per_stable, X3_per_down) %>% pivot_longer(cols = c(-Category))

#Generate a plot of the matrisome number changes for SF3b
out_bars <- ggplot(MA_bars, aes(x = Category, y = value, fill = name))+
  geom_bar(stat = "identity", colour = "black")+
  theme_classic()+
  coord_flip()+
  scale_fill_manual(values = c("red", "white", "blue"))

ggsave("./Consense_ECM_SF3b.pdf", device = "pdf", width = 10, height = 10, unit = "in")

#Correlation between the murine Tian et al and Below dataset
#Calculate correlation p and R value (pearson) between detasets 
corr_PDA_full = data.frame("label" = paste0("p: ", 
                                            round(broom::tidy(cor.test(MA_merge$Log2PDAvWT_CB, MA_merge$Log2PDAvWT))$p.value,9), 
                                            " R: ", 
                                            round(broom::tidy(cor.test(MA_merge$Log2PDAvWT_CB, MA_merge$Log2PDAvWT))$estimate,2)))

#Plot results and print in the correlation coefficients 
out_1 <- ggplot(MA_merge, aes(x= Log2PDAvWT_CB, y = Log2PDAvWT))+
  geom_point(fill = "red", alpha = 0.25, shape = 21, colour = "black")+
  geom_point(data = MA_merge %>% filter(Log2PDAvWT_CB >= 1 & Log2PDAvWT >=1), color = "black", alpha = 1, shape = 21, fill = "red")+
  geom_smooth(method = "lm", formula = y~x, se = F, colour = "black", linetype = 3, alpha = 0.75)+
  theme_classic()+
  geom_hline(yintercept = 1, alpha = 0.5, linetype = 2)+
  geom_vline(xintercept = 1, alpha = 0.5, linetype = 2)+
  theme(aspect.ratio = 1)+
  xlim(-5,5)+
  ylim(-2, 3.5)+
  geom_text(data = corr_PDA_full, aes(x=-3, 
                                      y = 3.5, 
                                      label = label) 
  )+
  border()+
  xlab("Log2FC(PDA/wt)")+
  ylab("Log2FC(PDA/wt) \n Tian et al 2019")

#Add margine plots 
out_2 <- ggMarginal(
  out_1,
  type = 'density',
  margins = 'both',
  size = 10,
  colour = 'black',
  fill = 'red',
  alpha = 0.25
)

#Save the plots 
ggsave("./1)_SF4a_Corr_murine_full.pdf", out_2, device = "pdf", width = 5, height = 5, unit = "in")

#Show proteins with a log2FC PDAvWT >=1 from both datasets 
out_3 <- ggplot(MA_merge %>% filter(Log2PDAvWT_CB >= 1 & Log2PDAvWT >=1), aes(x= Log2PDAvWT_CB, y = Log2PDAvWT, label = Gene_name, fill = Category))+
  geom_point(shape = 21, size = 2, colour = "black")+
  theme_classic()+
  theme(aspect.ratio = 1,
        legend.position = c(0.75, 0.75))+
  geom_text_repel( color = "black", size = 3)+
  border()+
  xlim(1,5)+
  ylim(1, 3.5)

ggsave("./1)_SF4a_Corr_murine_up.pdf", out_3, device = "pdf", width = 5, height = 5, unit = "in")


#PLots with Core matrisome correlation only 
corr_PDA_c = data.frame("label" = paste0("p: ", 
                                         round(broom::tidy(cor.test(MA_merge_c$Log2PDAvWT_CB, MA_merge_c$Log2PDAvWT))$p.value,7), 
                                         " R: ", 
                                         round(broom::tidy(cor.test(MA_merge_c$Log2PDAvWT_CB, MA_merge_c$Log2PDAvWT))$estimate,2)))

out_4 <- ggplot(MA_merge_c, aes(x= Log2PDAvWT_CB, y = Log2PDAvWT))+
  geom_point(fill = "red", alpha = 0.25, shape = 21, colour = "black")+
  geom_point(data = MA_merge_c %>% filter(Log2PDAvWT_CB >= 1 & Log2PDAvWT >=1), color = "black", alpha = 1, shape = 21, fill = "red")+
  geom_smooth(method = "lm", formula = y~x, se = F, colour = "black", linetype = 3, alpha = 0.75)+
  theme_classic()+
  geom_hline(yintercept = 1, alpha = 0.5, linetype = 2)+
  geom_vline(xintercept = 1, alpha = 0.5, linetype = 2)+
  theme(aspect.ratio = 1)+
  xlim(-5,5)+
  ylim(-2, 3.5)+
  geom_text(data = corr_PDA_c, aes(x=-3, 
                                   y = 3.5, 
                                   label = label) 
  )+
  border()+
  xlab("Log2FC(PDA/wt)")+
  ylab("Log2FC(PDA/wt) \n Tian et al 2019")

out_5 <- ggMarginal(
  out_4,
  type = 'density',
  margins = 'both',
  size = 10,
  colour = 'black',
  fill = 'red',
  alpha = 0.25
)


ggsave("./2)_SF4a_Corr_murine_coreMA_full.pdf", out_5, device = "pdf", width = 5, height = 5, unit = "in")


out_6 <- ggplot(MA_merge_c %>% filter(Log2PDAvWT_CB >= 1 & Log2PDAvWT >=1), aes(x= Log2PDAvWT_CB, y = Log2PDAvWT, label = Gene_name, fill = Category))+
  geom_point(shape = 21, size = 2, colour = "black")+
  theme_classic()+
  theme(aspect.ratio = 1,
        legend.position = c(0.75, 0.75))+
  geom_text_repel( color = "black", size = 3)+
  border()+
  xlim(1,5)+
  ylim(1, 3.5)

ggsave("./2)_SF4a_Corr_murine_coreMA_up.pdf", out_6, device = "pdf", width = 5, height = 5, unit = "in")


#Correlation of Below et al dataset with human Tian et al 2019 PNAS dataset 
#Compare with human data 
TH_MA_h <- read_csv("Tian2019_SD1D.csv") %>%
  select(Division = "Matrisome Division",
         Category = "Matrisome Category",
         Gene = "Entrez Gene Symbol",
         N1:PD4)

#Get mean for wt and all PDA samples 
TH_MA_h$mean_wt = apply(TH_MA_h[,4:5], 1, mean)
TH_MA_h$mean_PDA = apply(TH_MA_h[,10:20], 1, mean)

#Reformat gene names to merge tables 
TH_MA_h <- TH_MA_h %>% mutate(Log2PDAvWT = mean_PDA - mean_wt,
                              Gene = str_to_title(Gene)) %>%
  select(Gene_name = Gene, Division, Category, Log2PDAvWT)

#Merge tables 
MA_merge_h <- inner_join(MA_CB_merge, TH_MA_h, by = "Gene_name")
MA_merge_hc <- MA_merge_h %>% filter(Division == "Core matrisome")

#Save the data table 
write.csv(MA_merge_h, "./Below_Tian_inner_mean_human.csv", na = "")

#Correlation and plotting of the results 
#Correlte datasets and pring p-value and rho-value (spearman)
corr_PDA_full_h = data.frame("label" = paste0("p: ", 
                                              round(broom::tidy(cor.test(MA_merge_h$Log2PDAvWT_CB, MA_merge_h$Log2PDAvWT, method = "spearman"))$p.value,7), 
                                              " R: ", 
                                              round(broom::tidy(cor.test(MA_merge_h$Log2PDAvWT_CB, MA_merge_h$Log2PDAvWT, method = "spearman"))$estimate,2)))

#Generate plot as conducted above 
out_7 <- ggplot(MA_merge_h, aes(x= Log2PDAvWT_CB, y = Log2PDAvWT))+
  geom_point(fill = "red", alpha = 0.25, shape = 21, colour = "black")+
  geom_point(data = MA_merge_h %>% filter(Log2PDAvWT_CB >= 1 & Log2PDAvWT >=1), color = "black", alpha = 1, shape = 21, fill = "red")+
  geom_smooth(method = "lm", formula = y~x, se = F, colour = "black", linetype = 3, alpha = 0.75)+
  theme_classic()+
  geom_hline(yintercept = 1, alpha = 0.5, linetype = 2)+
  geom_vline(xintercept = 1, alpha = 0.5, linetype = 2)+
  theme(aspect.ratio = 1)+
  xlim(-6,6)+
  ylim(-1, 2.5)+
  geom_text(data = corr_PDA_full_h, aes(x=-3, 
                                        y = 2.5, 
                                        label = label) 
  )+
  border()+
  xlab("Log2FC(PDA/wt)")+
  ylab("Log2FC(PDA/wt) \n Tian et al 2019")

out_8 <- ggMarginal(
  out_7,
  type = 'density',
  margins = 'both',
  size = 10,
  colour = 'black',
  fill = 'red',
  alpha = 0.25
)

ggsave("./3)_SF4b_Corr_human_full.pdf", out_8, device = "pdf", width = 5, height = 5, unit = "in")


out_9 <- ggplot(MA_merge_h %>% filter(Log2PDAvWT_CB >= 1 & Log2PDAvWT >=1), aes(x= Log2PDAvWT_CB, y = Log2PDAvWT, label = Gene_name, fill = Category))+
  geom_point(shape = 21, size = 2, colour = "black")+
  theme_classic()+
  theme(aspect.ratio = 1,
        legend.position = c(0.75, 0.75))+
  geom_text_repel( color = "black", size = 3)+
  border()+
  xlim(1,6)+
  ylim(1, 2.5)

ggsave("./3)_SF4b_Corr_human_up.pdf", out_9, device = "pdf", width = 5, height = 5, unit = "in")


#Only core matrisome 
corr_PDA_full_hc = data.frame("label" = paste0("p: ", 
                                               round(broom::tidy(cor.test(MA_merge_hc$Log2PDAvWT_CB, MA_merge_hc$Log2PDAvWT, method = "spearman"))$p.value,4), 
                                               " R: ", 
                                               round(broom::tidy(cor.test(MA_merge_hc$Log2PDAvWT_CB, MA_merge_hc$Log2PDAvWT, method = "spearman"))$estimate,2)))


out_10 <- ggplot(MA_merge_hc, aes(x= Log2PDAvWT_CB, y = Log2PDAvWT))+
  geom_point(fill = "red", alpha = 0.25, shape = 21, colour = "black")+
  geom_point(data = MA_merge_hc %>% filter(Log2PDAvWT_CB >= 1 & Log2PDAvWT >=1), color = "black", alpha = 1, shape = 21, fill = "red")+
  geom_smooth(method = "lm", formula = y~x, se = F, colour = "black", linetype = 3, alpha = 0.75)+
  theme_classic()+
  geom_hline(yintercept = 1, alpha = 0.5, linetype = 2)+
  geom_vline(xintercept = 1, alpha = 0.5, linetype = 2)+
  theme(aspect.ratio = 1)+
  xlim(-6,6)+
  ylim(-1, 2.5)+
  geom_text(data = corr_PDA_full_hc, aes(x=-3, 
                                         y = 2.5, 
                                         label = label) 
  )+
  border()+
  xlab("Log2FC(PDA/wt)")+
  ylab("Log2FC(PDA/wt) \n Tian et al 2019")

out_11 <- ggMarginal(
  out_10,
  type = 'density',
  margins = 'both',
  size = 10,
  colour = 'black',
  fill = 'red',
  alpha = 0.25
)

ggsave("./4)_SF4b_Corr_core_human_full.pdf", out_11, device = "pdf", width = 5, height = 5, unit = "in")



out_12 <- ggplot(MA_merge_hc %>% filter(Log2PDAvWT_CB >= 1 & Log2PDAvWT >=1), aes(x= Log2PDAvWT_CB, y = Log2PDAvWT, label = Gene_name, fill = Category))+
  geom_point(shape = 21, size = 2, colour = "black")+
  theme_classic()+
  theme(aspect.ratio = 1,
        legend.position = c(0.75, 0.75))+
  geom_text_repel( color = "black", size = 3)+
  border()+
  xlim(1,6)+
  ylim(1, 2.5)

ggsave("./4)_SF4b_Corr_core_human_up.pdf", out_12, device = "pdf", width = 5, height = 5, unit = "in")




#Get List of murine proteins with a significant change between wt and PDA in both datasets 
up_set_h  <- MA_merge_h %>% filter(Log2PDAvWT >= 1 & Log2PDAvWT_CB >= 1) %>% mutate(h_gene = str_to_upper(Gene_name))
up_set_m <- MA_merge %>% filter(Log2PDAvWT >= 1 & Log2PDAvWT_CB >= 1) %>% mutate(h_gene = str_to_upper(Gene_name))

#Save data as csv or tsv
write_tsv(up_set_h, "./ECM_upregulated_sets_human.txt.gz")
write_tsv(up_set_m, "./ECM_upregulated_sets_mouse.txt.gz")
write_csv(up_set_h, "./ECM_upregulated_sets_human.csv")
write_csv(up_set_m, "./ECM_upregulated_sets_mouse.csv")


#Part II
#Check the survival impact for those genes on the TCGA cohort by using the automatic part of the 16) TCGA_individual.R script 
#Automatic module for a set of genes

#Get the RNA data - downloaded form CBioPortal
RNA_input <- read_tsv("./data_RNA_Seq_v2_expression_median.txt") 


#Get the clinical data - downloaded form CBioPortal
CD_sdata <- read_tsv("./data_bcr_clinical_data_sample.txt", skip = 4) 
CD_input <- read_tsv("./data_bcr_clinical_data_patient.txt", skip = 4) %>%
  left_join(CD_sdata, by = c("PATIENT_ID")) %>%
  select(PATIENT_ID, SAMPLE_ID, ONCOTREE_CODE, CANCER_TYPE, OS_MONTHS, DFS_MONTHS, OS_STATUS, DFS_STATUS) 


#Prepare the RNA_log_input file 
RNA_log_input <- modify_at(RNA_input, .at = vars(-Hugo_Symbol, -Entrez_Gene_Id), function(x){as.numeric(x)+1}) %>% 
  modify_at(.at = vars(-Hugo_Symbol, -Entrez_Gene_Id), log2) %>% select(-Hugo_Symbol) %>% 
  na.exclude() 


#Define helper function to iterate every gene over the RNAseq data and get p-value and HR for quantile stratified patients 
set_tester <- function(tbl, input, CD_input){
  igene <- tbl$enrez
  
  input <- input %>% filter(Entrez_Gene_Id == igene)
  
  if(NROW(input) == 0){res = NA
  }else{
    RNA_log <- input %>%
      column_to_rownames("Entrez_Gene_Id") %>%
      t %>%
      as.data.frame() %>%
      select(gene = 1) %>%
      rownames_to_column("sample") %>%
      inner_join(CD_input, by = c("sample" = "SAMPLE_ID")) %>%
      mutate(gene_set_med = ifelse(gene <= median(gene), "lower 50%", "upper 50%"),
             status = ifelse(OS_STATUS == "LIVING", 0, 1),
             gene_set_quant = ifelse(gene <= broom::tidy(quantile(gene))[2,]$x, "lower 25%", ifelse( gene >= broom::tidy(quantile(gene))[4,]$x, "upper 25%", "other")))
    
    surv_input <- RNA_log %>% mutate(status = as.numeric(status),
                                     OS_MONTHS = as.numeric(OS_MONTHS))
   
    write.csv(surv_input %>% select(SAMPLE_ID = sample, 
                                    PATIENT_ID, 
                                    CANCER_TYPE, 
                                    GENE_EXPRESSION = gene, 
                                    OS_MONTHS, 
                                    OS_STATUS, 
                                    NUMERIC_OS_STATUS = status,
                                    QUANTILE_STRATIFICATION = gene_set_quant) %>%
                arrange(GENE_EXPRESSION), 
              paste0("./survival_data/", tbl$h_gene, "_surv_data_h.csv"))
    
    res.cox <- coxph(Surv(OS_MONTHS, status) ~ gene_set_quant, data = surv_input %>% filter(gene_set_quant != "other"))
    
    res = data.frame("cox_p" = broom::tidy(res.cox)$p.value, "HR" = exp((broom::tidy(res.cox))$estimate))
  return(res)}}


#Convert h_gene to entrez_gene_id using biomart
#Get h_genes from the up_set
h_genes <- up_set_h$h_gene
trans_gene_h <- biomaRt::getBM(attributes = c("external_gene_name", "entrezgene_id"),
                             filters = "external_gene_name",
                             values = h_genes,
                             mart = ensembl)

#Reformat and prepare the input table for set_tester
up_set_surv_h <- up_set_h %>% 
  left_join(trans_gene_h %>% distinct(), by = c("h_gene"="external_gene_name")) %>%
  select(Gene_name, h_gene, enrez = entrezgene_id) %>% 
  group_by(Gene_name) %>% 
  nest() %>% 
  ungroup() 


#Execute the function, returns p-values and HR's and saves raw survival data 
up_set_input_h <- up_set_surv_h %>% 
  mutate(data2 = map(.x = data, .f = set_tester, input = RNA_log_input, CD_input = CD_input)) %>% 
  select(-data) %>% unnest(cols = c(data2)) %>% 
  filter(!is.na(cox_p)) #%>% mutate(HR = HR*-1)

#Merge up_set_input_h with 
up_set_h_output <- up_set_h %>% 
  left_join(trans_gene_h, by = c("h_gene" = "external_gene_name")) %>%
  left_join(up_set_input_h, by = c("Gene_name" = "Gene_name")) %>%
  select(murine_Gene_name = Gene_name, 
         human_gene_name = h_gene, 
         entrez_gene_name = entrezgene_id, 
         Division = Division.x, 
         Category = Category.x,
         Log2PDAvNP_Below = Log2PDAvWT_CB,
         Log2PDAvNP_Tian = Log2PDAvWT,
         Cox_regression_p_value = cox_p,
         Hazard_ratio = HR) %>%
  arrange(-Hazard_ratio)

#Survival output
write.csv(up_set_h_output, "./2020_SF4b_SurvOutput_h.csv", na = "", row.names = F)


#Derive a subfunction to reverse a log10 transformed axis to display HR
reverselog_trans <- function(base = exp(1)) {
  trans <- function(x) -log(x, base)
  inv <- function(x) base^(-x)
  trans_new(paste0("reverselog-", format(base)), trans, inv, 
            log_breaks(base = base), 
            domain = c(1e-100, Inf))
}

#Create plot of HR over p-value
out_13 <- ggplot(up_set_input_h, aes(x = HR, y = cox_p))+
  geom_point(alpha = ifelse(up_set_input_h$cox_p <= 0.05, 1, 0.25), fill = "red", size = 3, shape = 21)+
  theme_classic()+
  scale_y_continuous(trans=reverselog_trans(10))+
  scale_x_continuous(trans = "log10")+
  #xlim(0, 4)+
  xlab("Hazard Ratio [Log10]")+
  ylab("Cox regression p-value [Log10]")+
  geom_hline(yintercept = 0.05)+
  theme(aspect.ratio = 2)+
  border()+
  geom_text_repel(data = up_set_input_h %>% filter(cox_p <= 0.05), aes(label = Gene_name))

#Save output
ggsave("./2020_SF4b_hECM_surv_plot.pdf", out_13, device = "pdf", width = 5, height = 5, unit = "in")


#Conduct the same analysis for murine genes (humanize gene names)
#Format the input data
m_genes <- up_set_m$h_gene

#get entrez IDs for input
trans_gene_m <- biomaRt::getBM(attributes = c("external_gene_name", "entrezgene_id"),
                               filters = "external_gene_name",
                               values = m_genes,
                               mart = ensembl)

#Join the tables
up_set_surv_m <- up_set_m %>% 
  left_join(trans_gene_m %>% distinct(), by = c("h_gene"="external_gene_name")) %>%
  select(Gene_name, h_gene, enrez = entrezgene_id) %>% 
  group_by(Gene_name) %>% 
  nest() %>% 
  ungroup() 

#Execute set_tester function to get survival annotations 
up_set_input_m <- up_set_surv_m %>% 
  mutate(data2 = map(.x = data, .f = set_tester, input = RNA_log_input, CD_input = CD_input)) %>% 
  select(-data) %>% unnest(cols = c(data2)) %>% 
  filter(!is.na(cox_p)) 

#Reformat the output 
up_set_m_output <- up_set_m %>% 
  left_join(trans_gene_m, by = c("h_gene" = "external_gene_name")) %>%
  left_join(up_set_input_m, by = c("Gene_name" = "Gene_name")) %>%
  select(murine_Gene_name = Gene_name, 
         human_gene_name = h_gene, 
         entrez_gene_name = entrezgene_id, 
         Division = Division, 
         Category = Category,
         Log2PDAvNP_Below = Log2PDAvWT_CB,
         Log2PDAvNP_Tian = Log2PDAvWT,
         Cox_regression_p_value = cox_p,
         Hazard_ratio = HR) %>%
  arrange(-Hazard_ratio)

#Save the data 
write.csv(up_set_m_output, "./2020_SF4b_SurvOutput_m.csv.csv", na = "", row.names = F)


#Plot for murine ECM proteins 
out_14 <- ggplot(up_set_input_m, aes(x = HR, y = cox_p))+
  geom_point(alpha = ifelse(up_set_input_m$cox_p <= 0.05, 1, 0.25), fill = "red", size = 3, shape = 21)+
  theme_classic()+
  scale_y_continuous(trans=reverselog_trans(10))+
  scale_x_continuous(trans = "log10")+
  #xlim(-4, 4)+
  xlab("Hazard Ratio [Log10]")+
  ylab("Cox regression p-value [Log10]")+
  geom_hline(yintercept = 0.05)+
  theme(aspect.ratio = 2)+
  border()+
  geom_text_repel(data = up_set_input_m %>% filter(cox_p <= 0.05), aes(label = Gene_name))

ggsave("./2020_SF4a_mECM_surv_plot.pdf", out_14, device = "pdf", width = 5, height = 5, unit = "in")
